@@ -1,6 +1,6 @@
 package Outthentic;
 
-our $VERSION = '0.2.17';
+our $VERSION = '0.2.18';
 
 1;
 
@@ -176,6 +176,9 @@ sub run_story_file {
         set_prop( stdout => get_stdout() );
         set_prop( scenario_status => 1 );
 
+        Outthentic::Story::Stat->set_scenario_status(1);
+        Outthentic::Story::Stat->set_stdout(get_stdout());
+
     }else{
 
 
@@ -213,15 +216,22 @@ sub run_story_file {
         my ($st, $out) = execute_cmd2($story_command);
 
         if ($st) {
-            outh_ok(1, "scenario succeeded");
+            outh_ok(1, "scenario succeeded" );
             set_prop( scenario_status => 1 );
+            Outthentic::Story::Stat->set_scenario_status(1);
+            Outthentic::Story::Stat->set_stdout($out);
+
         }elsif(ignore_story_err()){
             outh_ok(1, "scenario failed, still continue due to `ignore_story_err' is set");
             set_prop( scenario_status => 2 );
+            Outthentic::Story::Stat->set_scenario_status(2);
+            Outthentic::Story::Stat->set_stdout($out);
         }else{
             outh_ok(0, "scenario succeeded");
             set_prop( scenario_status => 0 );
-
+            Outthentic::Story::Stat->set_scenario_status(0);
+            Outthentic::Story::Stat->set_stdout($out);
+            Outthentic::Story::Stat->set_status(0);
         }
 
         set_prop( stdout => $out );
@@ -277,7 +287,11 @@ sub generate_asserts {
 
     for my $r ( @{dsl()->results}){
         note($r->{message}) if $r->{type} eq 'debug';
-        outh_ok($r->{status}, $r->{message}) if $r->{type} eq 'check_expression';
+        if ($r->{type} eq 'check_expression' ){
+          Outthentic::Story::Stat->add_check_stat($r);
+          outh_ok($r->{status}, $r->{message}); 
+          Outthentic::Story::Stat->set_status(0) unless $r->{status};
+        };
 
     }
 
@@ -289,9 +303,11 @@ sub generate_asserts {
 
 }
 
+      
+
 sub outh_ok {
 
-    my $st = shift;
+    my $st      = shift;
     my $message = shift;
 
     if ($st) {
@@ -341,7 +357,7 @@ sub short_story_name {
 
     }
 
-    return $short_story_dir;
+    return $short_story_dir.' '.story_vars_pretty();
 }
 
 END {
